@@ -10,6 +10,7 @@ use crate::util;
 use crate::*;
 
 /// Builder for creating an [`OpenObject`]. Typically the entry point into libbpf-rs.
+#[derive(Default)]
 pub struct ObjectBuilder {
     name: String,
     relaxed_maps: bool,
@@ -116,15 +117,6 @@ impl ObjectBuilder {
     }
 }
 
-impl Default for ObjectBuilder {
-    fn default() -> Self {
-        ObjectBuilder {
-            name: String::new(),
-            relaxed_maps: false,
-        }
-    }
-}
-
 /// Represents an opened (but not yet loaded) BPF object file.
 ///
 /// Use this object to access [`OpenMap`]s and [`OpenProgram`]s.
